@@ -4,10 +4,6 @@ A framework for predicting T-cell clonal expansion from single-cell RNA sequenci
 using multiple machine learning approaches including autoencoders, MLPs, LightGBM, and linear models.
 """
 
-__version__ = "0.1.6"
-__author__ = "Ron Amit, Ofir Shorer"
-__email__ = "ron2amit@gmail.com, ofirshorer@campus.technion.ac.il"
-
 # Import core functionality
 from scxpand.core.inference import run_inference
 from scxpand.core.prediction import run_prediction_pipeline
